==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/type/shared/ora_config/common_grants_with_admin.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:common_grants_with_admin, :array_matching => :all) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::GrantProperty
  include Puppet_X::EnterpriseModules::Oracle::CreateOnly
  include Puppet_X::EnterpriseModules::Oracle::Mungers::Upcase

  desc <<-DESC
    Common grants for this user or role with admin.

    This property is only functional when applied on container databases.

    All the common grants this resource has. Here is an example on how to use this on an `ora_user`:

      ora_user { 'my_user@sid':
        ...
        common_grants_with_admin => ['UNLIMITED TABLESPACE', 'CREATE PUBLIC SYNONYM'].
        ...
      }

    Here is an example on how to use this on an `ora_role`:

      ora_ora_role { 'my_role@sid':
        ...
        common_grants_with_admin => ['UNLIMITED TABLESPACE', 'CREATE PUBLIC SYNONYM'].
        ...
      }

  DESC

  data_type('Optional[Array[String[1]]]')

  #
  # This property manages grants with admin options
  #
  def self.admin
    true
  end

  def self.common
    true
  end

  validate do |value|
    fail "#{value} is an invalid right. Use ora_object_permissions to set permissions on objects" if value.include?('.')
    fail "#{value} is an invalid right. Use ora_object_permissions to set permissions on objects" if value.include?(' on ')

    true
  end

  #
  # because the order may differ, but they are still the same,
  # to decide if they are equal, first do a sort on is and should
  #
  def insync?(is)
    is = [] if is.to_s == 'absent' || is.nil?
    is.sort == should.sort
  end

  def revoked_property_used?
    resource.revoked&.any?
  end

  def granted_property_used?
    resource.granted&.any?
  end

  def revoked_rights
    current_rights - value
  end

  def granted_rights
    value - current_rights
  end
end

==> enterprisemodules-ora_config-3.23.4.tar.gz: enterprisemodules-ora_config-3.23.4/lib/puppet/type/shared/ora_config/common_grants_with_admin.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:common_grants_with_admin, :array_matching => :all) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access
  include PuppetX::EnterpriseModules::Oracle::GrantProperty
  include PuppetX::EnterpriseModules::Oracle::CreateOnly
  include PuppetX::EnterpriseModules::Oracle::Mungers::Upcase

  desc <<-DESC
    Common grants for this user or role with admin.

    This property is only functional when applied on container databases.

    All the common grants this resource has. Here is an example on how to use this on an `ora_user`:

      ora_user { 'my_user@sid':
        ...
        common_grants_with_admin => ['UNLIMITED TABLESPACE', 'CREATE PUBLIC SYNONYM'].
        ...
      }

    Here is an example on how to use this on an `ora_role`:

      ora_ora_role { 'my_role@sid':
        ...
        common_grants_with_admin => ['UNLIMITED TABLESPACE', 'CREATE PUBLIC SYNONYM'].
        ...
      }

  DESC

  data_type('Optional[Array[String[1]]]')

  #
  # This property manages grants with admin options
  #
  def self.admin
    true
  end

  def self.common
    true
  end

  validate do |value|
    fail "#{value} is an invalid right. Use ora_object_permissions to set permissions on objects" if value.include?('.')
    fail "#{value} is an invalid right. Use ora_object_permissions to set permissions on objects" if value.include?(' on ')

    true
  end

  #
  # because the order may differ, but they are still the same,
  # to decide if they are equal, first do a sort on is and should
  #
  def insync?(is)
    is = [] if is.to_s == 'absent' || is.nil?
    is.sort == should.sort
  end

  def revoked_property_used?
    resource.revoked&.any?
  end

  def granted_property_used?
    resource.granted&.any?
  end

  def revoked_rights
    current_rights - value
  end

  def granted_rights
    value - current_rights
  end
end
